@@ -32,10 +32,10 @@
 #include <kpixmapregionselectordialog.h>
 
 #include <QtCore/QMimeData>
-#include <QtGui/QDrag>
-#include <QtGui/QDragEnterEvent>
-#include <QtGui/QDropEvent>
-#include <QtGui/QMenu>
+#include <QDrag>
+#include <QDragEnterEvent>
+#include <QDropEvent>
+#include <QMenu>
 
 /**
  * @short Small helper class to load image from network
@@ -48,7 +48,6 @@ class ImageLoader
     QImage loadImage( const KUrl &url, bool *ok );
 
   private:
-    QImage mImage;
     QWidget *mParent;
 };
 
@@ -63,23 +62,24 @@ QImage ImageLoader::loadImage( const KUrl &url, bool *ok )
   QImage image;
   QString tempFile;
 
-  if ( url.isEmpty() )
+  if ( url.isEmpty() ) {
     return image;
+  }
 
-  (*ok) = false;
+  ( *ok ) = false;
 
   if ( url.isLocalFile() ) {
     if ( image.load( url.toLocalFile() ) ) {
-      (*ok) = true;
+      ( *ok ) = true;
     }
   } else if ( KIO::NetAccess::download( url, tempFile, mParent ) ) {
     if ( image.load( tempFile ) ) {
-      (*ok) = true;
+      ( *ok ) = true;
     }
     KIO::NetAccess::removeTempFile( tempFile );
   }
 
-  if ( !(*ok) ) {
+  if ( !( *ok ) ) {
     // image does not exist (any more)
     KMessageBox::sorry( mParent, i18n( "This contact's image cannot be found." ) );
     return image;
@@ -89,7 +89,7 @@ QImage ImageLoader::loadImage( const KUrl &url, bool *ok )
 
   image = KPixmapRegionSelectorDialog::getSelectedImage( pixmap, 1, 1, mParent );
   if ( image.isNull() ) {
-    (*ok) = false;
+    ( *ok ) = false;
     return image;
   }
 
@@ -100,7 +100,7 @@ QImage ImageLoader::loadImage( const KUrl &url, bool *ok )
       image = image.scaledToWidth( 720 );
   }
 
-  (*ok) = true;
+  ( *ok ) = true;
 
   return image;
 }
@@ -122,10 +122,11 @@ ImageWidget::ImageWidget( Type type, QWidget *parent )
 
   connect( this, SIGNAL(clicked()), SLOT(changeImage()) );
 
-  if ( mType == Photo )
+  if ( mType == Photo ) {
     setToolTip( i18n( "The photo of the contact (click to change)" ) );
-  else
+  } else {
     setToolTip( i18n( "The logo of the company (click to change)" ) );
+  }
 
   updateView();
 }
@@ -137,10 +138,9 @@ ImageWidget::~ImageWidget()
 
 void ImageWidget::loadContact( const KABC::Addressee &contact )
 {
-  const KABC::Picture picture = (mType == Photo ? contact.photo() : contact.logo());
-  if ( picture.isIntern() && !picture.data().isNull() ) {
+  mPicture = ( mType == Photo ? contact.photo() : contact.logo() );
+  if ( mPicture.isIntern() && !mPicture.data().isNull() ) {
     mHasImage = true;
-    mImage = picture.data();
   }
 
   updateView();
@@ -148,10 +148,11 @@ void ImageWidget::loadContact( const KABC::Addressee &contact )
 
 void ImageWidget::storeContact( KABC::Addressee &contact ) const
 {
-  if ( mType == Photo )
-    contact.setPhoto( mImage );
-  else
-    contact.setLogo( mImage );
+  if ( mType == Photo ) {
+    contact.setPhoto( mPicture );
+  } else {
+    contact.setLogo( mPicture );
+  }
 }
 
 void ImageWidget::setReadOnly( bool readOnly )
@@ -162,12 +163,13 @@ void ImageWidget::setReadOnly( bool readOnly )
 void ImageWidget::updateView()
 {
   if ( mHasImage ) {
-    setIcon( QPixmap::fromImage( mImage ) );
+    setIcon( QPixmap::fromImage( mPicture.data() ) );
   } else {
-    if ( mType == Photo )
+    if ( mType == Photo ) {
       setIcon( KIcon( QLatin1String( "user-identity" ) ) );
-    else
+    } else {
       setIcon( KIcon( QLatin1String( "image-x-generic" ) ) );
+    }
   }
 }
 
@@ -179,12 +181,13 @@ void ImageWidget::dragEnterEvent( QDragEnterEvent *event )
 
 void ImageWidget::dropEvent( QDropEvent *event )
 {
-  if ( mReadOnly )
+  if ( mReadOnly ) {
     return;
+  }
 
   const QMimeData *mimeData = event->mimeData();
   if ( mimeData->hasImage() ) {
-    mImage = qvariant_cast<QImage>(mimeData->imageData());
+    mPicture.setData( qvariant_cast<QImage>( mimeData->imageData() ) );
     mHasImage = true;
     updateView();
   }
@@ -196,7 +199,7 @@ void ImageWidget::dropEvent( QDropEvent *event )
     bool ok = false;
     const QImage image = imageLoader()->loadImage( urls.first(), &ok );
     if ( ok ) {
-      mImage = image;
+      mPicture.setData( image );
       mHasImage = true;
       updateView();
     }
@@ -211,13 +214,13 @@ void ImageWidget::mousePressEvent( QMouseEvent *event )
 
 void ImageWidget::mouseMoveEvent( QMouseEvent *event )
 {
-  if ( (event->buttons() & Qt::LeftButton) &&
-       (event->pos() - mDragStartPos).manhattanLength() > KGlobalSettings::dndEventDelay() ) {
+  if ( ( event->buttons() & Qt::LeftButton ) &&
+       ( event->pos() - mDragStartPos ).manhattanLength() > KGlobalSettings::dndEventDelay() ) {
 
     if ( mHasImage ) {
       QDrag *drag = new QDrag( this );
       drag->setMimeData( new QMimeData() );
-      drag->mimeData()->setImageData( mImage );
+      drag->mimeData()->setImageData( mPicture.data() );
       drag->start();
     }
   }
@@ -228,24 +231,28 @@ void ImageWidget::contextMenuEvent( QContextMenuEvent *event )
   QMenu menu;
 
   if ( mType == Photo ) {
-    if ( !mReadOnly )
+    if ( !mReadOnly ) {
       menu.addAction( i18n( "Change photo..." ), this, SLOT(changeImage()) );
+    }
 
     if ( mHasImage ) {
       menu.addAction( i18n( "Save photo..." ), this, SLOT(saveImage()) );
 
-      if ( !mReadOnly )
+      if ( !mReadOnly ) {
         menu.addAction( i18n( "Remove photo" ), this, SLOT(deleteImage()) );
+      }
     }
   } else {
-    if ( !mReadOnly )
+    if ( !mReadOnly ) {
       menu.addAction( i18n( "Change logo..." ), this, SLOT(changeImage()) );
+    }
 
     if ( mHasImage ) {
       menu.addAction( i18n( "Save logo..." ), this, SLOT(saveImage()) );
 
-      if ( !mReadOnly )
+      if ( !mReadOnly ) {
         menu.addAction( i18n( "Remove logo" ), this, SLOT(deleteImage()) );
+      }
     }
   }
 
@@ -254,15 +261,16 @@ void ImageWidget::contextMenuEvent( QContextMenuEvent *event )
 
 void ImageWidget::changeImage()
 {
-  if ( mReadOnly )
+  if ( mReadOnly ) {
     return;
+  }
 
-  const KUrl url = KFileDialog::getOpenUrl( QString(), KImageIO::pattern(), this );
+  const KUrl url = KFileDialog::getOpenUrl( QUrl(), KImageIO::pattern(), this );
   if ( url.isValid() ) {
     bool ok = false;
     const QImage image = imageLoader()->loadImage( url, &ok );
     if ( ok ) {
-      mImage = image;
+      mPicture.setData( image );
       mHasImage = true;
       updateView();
     }
@@ -272,23 +280,24 @@ void ImageWidget::changeImage()
 void ImageWidget::saveImage()
 {
   const QString fileName = KFileDialog::getSaveFileName( KUrl(), KImageIO::pattern(), this );
-  if ( !fileName.isEmpty() )
-    mImage.save( fileName );
+  if ( !fileName.isEmpty() ) {
+    mPicture.data().save( fileName );
+  }
 }
 
 void ImageWidget::deleteImage()
 {
   mHasImage = false;
-  mImage = QImage();
+  mPicture.setData( QImage() );
   updateView();
 }
 
 ImageLoader* ImageWidget::imageLoader()
 {
-  if ( !mImageLoader )
+  if ( !mImageLoader ) {
     mImageLoader = new ImageLoader;
+  }
 
   return mImageLoader;
 }
 
-#include "imagewidget.moc"
