@@ -47,11 +47,7 @@ public:
 
 private:
   friend class InsertImageDialogPrivate;
-  InsertImageDialogPrivate *d;
-  Q_PRIVATE_SLOT( d, void _k_slotKeepOriginalSizeClicked(bool) )
-  Q_PRIVATE_SLOT( d, void _k_slotUrlChanged(const QString&))
-  Q_PRIVATE_SLOT( d, void _k_slotImageWidthChanged(int))
-  Q_PRIVATE_SLOT( d, void _k_slotImageHeightChanged(int))
+  InsertImageDialogPrivate * const d;
 };
 }
 
