@@ -329,30 +329,30 @@ TableActionMenu::TableActionMenu(KActionCollection *ac, TextEdit *textEdit)
     KActionMenu *insertMenu = new KActionMenu( i18n( "Insert" ), this );
     addAction( insertMenu );
 
-    d->actionInsertTable = new KAction( i18n( "Table..." ), this );
+    d->actionInsertTable = new KAction( KIcon(QLatin1String("table")), i18n( "Table..." ), this );
     insertMenu->addAction( d->actionInsertTable );
     ac->addAction( QLatin1String( "insert_new_table" ), d->actionInsertTable );
     connect( d->actionInsertTable, SIGNAL(triggered(bool)), SLOT(_k_slotInsertTable()) );
 
     insertMenu->addSeparator();
-    d->actionInsertRowBelow = new KAction( i18n( "Row Below" ), this );
+    d->actionInsertRowBelow = new KAction( KIcon(QLatin1String("edit-table-insert-row-below")), i18n( "Row Below" ), this );
     insertMenu->addAction( d->actionInsertRowBelow );
     ac->addAction( QLatin1String( "insert_row_below" ), d->actionInsertRowBelow );
     connect( d->actionInsertRowBelow, SIGNAL(triggered(bool)), SLOT(_k_slotInsertRowBelow()) );
 
-    d->actionInsertRowAbove = new KAction( i18n( "Row Above" ), this );
+    d->actionInsertRowAbove = new KAction( KIcon(QLatin1String("edit-table-insert-row-above")), i18n( "Row Above" ), this );
     insertMenu->addAction( d->actionInsertRowAbove );
     ac->addAction( QLatin1String( "insert_row_above" ), d->actionInsertRowAbove );
     connect( d->actionInsertRowAbove, SIGNAL(triggered(bool)), SLOT(_k_slotInsertRowAbove()) );
 
     insertMenu->addSeparator();
-    d->actionInsertColumnBefore = new KAction( i18n( "Column Before" ), this );
+    d->actionInsertColumnBefore = new KAction( KIcon(QLatin1String("edit-table-insert-column-left")), i18n( "Column Before" ), this );
     insertMenu->addAction( d->actionInsertColumnBefore );
     ac->addAction( QLatin1String( "insert_column_before" ), d->actionInsertColumnBefore );
 
     connect( d->actionInsertColumnBefore, SIGNAL(triggered(bool)), SLOT(_k_slotInsertColumnBefore()) );
 
-    d->actionInsertColumnAfter = new KAction( i18n( "Column After" ), this );
+    d->actionInsertColumnAfter = new KAction( KIcon(QLatin1String("edit-table-insert-column-right")), i18n( "Column After" ), this );
     insertMenu->addAction( d->actionInsertColumnAfter );
     ac->addAction( QLatin1String( "insert_column_after" ), d->actionInsertColumnAfter );
     connect( d->actionInsertColumnAfter, SIGNAL(triggered(bool)), SLOT(_k_slotInsertColumnAfter()) );
@@ -383,13 +383,13 @@ TableActionMenu::TableActionMenu(KActionCollection *ac, TextEdit *textEdit)
     connect( d->actionRemoveColumnAfter, SIGNAL(triggered(bool)), SLOT(_k_slotRemoveColumnAfter()) );
     addSeparator();
 
-    d->actionMergeCell = new KAction( i18n( "Join With Cell to the Right" ), this );
+    d->actionMergeCell = new KAction( KIcon(QLatin1String("edit-table-cell-merge")), i18n( "Join With Cell to the Right" ), this );
     ac->addAction( QLatin1String( "join_cell_to_the_right" ), d->actionMergeCell );
     connect( d->actionMergeCell, SIGNAL(triggered(bool)), SLOT(_k_slotMergeCell()) );
     addAction( d->actionMergeCell );
     addSeparator();
 
-    d->actionSplitCell = new KAction( i18n( "Split cells" ), this );
+    d->actionSplitCell = new KAction( KIcon(QLatin1String("edit-table-cell-split")), i18n( "Split cells" ), this );
     ac->addAction( QLatin1String( "split_cells" ), d->actionSplitCell );
     connect( d->actionSplitCell, SIGNAL(triggered(bool)), SLOT(_k_slotSplitCell()) );
     addAction( d->actionSplitCell );
